# telus-bulk-types-pypi

## Import models using

    from telus_bulk.models

## E.g
    from telus_bulk.models.worker_job import AddressProcessingJob
    job_data: AddressProcessingJob = AddressProcessingJob.parse_raw(message.data)

# Changelog

1.1.0:
- Added more AMS fields to PlaceAMS, First demo ready!

1.0.7:
- Added more AMS fields to PlaceAMS

1.0.6:
- Partner list bug fix

1.0.5:
- Added supported partners enum and list  

1.0.3:
- Optional AMS Coordinates object fields, except for latitude and longitude

1.0.2:
- Added CityCoverageProcessedJob class
- CSQI service supports a PlaceAms as Place